
# Serasa Remssa

Pacote criado para facilitar a integração com a API do Serasa, tanto para geração de remessas de negativação quanto para consultas à documentos.

## Estrutura de diretórios

```
SERASA_REMESSA
└───src
    ├───Cnab600
    ├───Http
    │   └───Advanced
    │       └───PF
    │           ├───Blocks
    │           └───SubTypes
    │               └───F900
    └───Utils
```

```
Schaffen\SerasaRemessa\Cnab600
```

## Consulta Avançada documento

### Consulta a CPF

A consulta a CPF está implementada em:

```
Schaffen\SerasaRemessa\Http\Advanced\PF
```

*A consulta avançada a CNPJ ainda não foi implementada

### Consulta Basica CPF/CNPJ 

Ainda não finalizada


## Uso/Exemplos

Exemplo de geração de remssa de negativação

```php
<?php
use Schaffen\SerasaRemessa\Cnab600\Shipping;

class NegativacaoController {
    public function negativar() {
        // Configuração com dados da empresa que está enviando a negativação
        $configuracao = [
            "cnpj_key" => "", // 8 primeiros dígitos do CPNJ
            "cnpj_branch_digit" => "", // Digito da filial no CPNJ
            "move_date" => "", // Data da movimentação no formato 'Y-m-d'
            "phone_ddd" => "", // DDD do contato da empresa
            "phone_number" => "", // Número do contato da empresa
            "phone_ext" => "", // Extenção do número do contato da empresa
            "contact" => "", // Nome do contato da empresa
            "shipping_sequence" => "", // Sequencia da remessa (Manter atualizada)
            "shipping_differential" => "", // Caso enviar mais de uma remessa independentes por deptos.,
            "logon" => "", // Logon da emrpesa no Serasa
            "send_code" => "E" // Código do tipo da Remessa, 'E' para envio
        ];

        // Lista de pessoas a serem negativadas
        $pessoas = [
            [
                "operation" => "", // Operação, 'I' (inclusão) ou 'E' (exclusão)
                "occurrence_date" => "", // Data da ocorrencia
                "contract_end_date" => "", // Data do fim do contrato
                "nature_code" => "", // Código de natureza da operação
                "embratel_code" => "", // Código da praça Embratel
                "person_type" => "",  // Tipo de pessoa do principal 'F' ou 'J'
                "person_fisrt_document_type" => "2", // Tipo do primeiro documento do principal (1 - CNPJ, 2 - CPF)
                "person_first_document" => "", // Primeiro documento do principal 
                "discharge_reason" => "", // Motivo da Baixa, (Caso remoção de negativação)
                "person_second_document_type" => "", // Tipo do segundo documento do principal (3 - RG)
                "person_second_document" => "", // Segundo documento do principal
                "person_second_document_uf" => "", // UF do RG do principal
                "guarantor_type" => "", // Tipo de pessoa do coobrigado ('F' ou 'J') 
                "guarantor_fisrt_document_type" => "", // Tipo do primeiro documento do coobrigado (1 - CNPJ, 2 - CPF)
                "guarantor_first_document" => "", // Primeiro documento do coobrigado
                "guarantor_second_document_type" => "", // Tipo do segundo documento do coobrigado (3 - RG)
                "guarantor_second_document" => "", // Segundo documento do coobrigado
                "guarantor_second_document_uf" => "", // UF do RG do coobrigado
                "person_name" => "", // Nome do principal
                "person_birthdate" => "", // Data de nascimento do principal
                "person_father_name" => "", // Nome do pai do principal
                "person_mother_name" => "", // Nome da mãe do principal
                "person_full_address" => "", // Endereço do principal
                "person_neighborhood" => "", // Bairro do principal
                "person_city" => "", // Cidade do principal
                "person_uf" => "", // Estado do principal
                "person_cep" => "", // CEP do principal
                "unpaid_value" => "", // Valor da dívida
                "contract_number" => "", // Número do contrato
                "our_number" => "", // Nosso número
                "person_phone_ddd" => "", // DDD do principal
                "person_phone_number" => "", // Número do principal
                "contract_start_date" => "", // Data do inicio do contrato
                "contract_value" => "", // Valor do contrato
                "communication_type" => // Tipo de comunicação
            ]
        ]

        $shipping = new Shipping($configuracao, $pessoas);
        $cnab = $shipping->make();
        return $cnab;

    }
}
```

Exemplo de consulta a CPF no Serasa

```php
<?php
use Schaffen\SerasaRemessa\Http\Advanced\PF\Query;

class ConsultaController {
    public function consultarCpf($cpf) {
        $logon = "XXXXXXXX"; // Logon da empresa na API do Serasa
        $password = "********"; // Senha da empresa na API do Serasa
        $url = "http://"; // URL da api do serasa

        $query = new Query($logon, $password, [
            'document' =>  "", // CPF a ser consultado
        ]);

        // Retorna os dados formatados
        return $query->send($url);
    }
}
```


## Contribuindo

### Adicionando/Editando Registros

Caso seja necessário editar ou adicionar outros blocos às regras atuais basta implementar uma nova classe no extendendo a classe ```Record``` 

Exemplo:

```php
class NovoRegistro extends Schaffen\SerasaRemessa\Utils\Record {
    /**
     * @var array Lista de colunas esperadas para o bloco
     */
    protected $templateColumns = [
       // ...
    ];
}
```

Os itens da array ```$templateColumns``` devem ser arrays no formato a seguir:
```php
    [
        /** 
         * @var string nome do atributo 
         */
        'name' => null, 
         /** 
          * @var int posição da coluna no registro 
         */
        'position' => null,
        /** 
         * @var int número de caracteres da coluna 
         * */
        'size' => null, 
        /** 
         * @var string tipo de dado da coluna 
         * */
        'type' =>  null, 
    ]
```
## Referência

 - [Documentação do CNAB 600 da Serasa](https://drive.google.com/file/d/1E-YbEFqM4YlV3WX5IT-DUYidtQSGdBCT/view?usp=drive_link)

 - [Documentação Consulta Avançada PF](https://drive.google.com/file/d/13WQQKcHUvmXv6eA9tekp5w5YiZcyEUCM/view?usp=sharing)

 - [Documentação Consulta Avançada PJ](https://drive.google.com/file/d/1ys9QVe-BmucpGrvO0SY7aRO6yMqVH4ai/view?usp=sharing)

 - [Documentação Consulta Básica PF/PJ](https://drive.google.com/file/d/1ux63mmXLcTtekmZ1IA_067n_bzYbLYFX/view?usp=sharing)




